@@ -155,8 +155,35 @@ relocate_vars <- function(data) {
   stop(api_status_check$code, ':\n', api_status_check$message)
 }
 
+unnest_safe <- function(x, ...) {
+
+  # if x is a list instead of a dataframe, something went wrong (happens sometimes in
+  # meteogalicia or meteocat).
+  if (inherits(x, 'list')) {
+    stop(glue::glue(
+      "Something went wrong, no data.frame returned, but a list with the following names {names(x)} and the following contents {glue::glue_collapse(x, sep = '\n')}"
+    ))
+  }
+
+  # now, we need to check if "x" is NULL. Sometimes the list of dataframes is not complete, with
+  # some elements being NULL. This happens for example in meteocat with some variables before 2010.
+  # If this happens, we must return something, instead of processing the data with dplyr::unnest.
+  if (is.null(x) || nrow(x) < 1) {
+    return(dplyr::tibble())
+  }
+
+  return(tidyr::unnest(x, ...))
+
+}
+
 # test helpers ------------------------------------------------------------------------------------------
 
+skip_if_no_internet <- function() {
+  if (!curl::has_internet()) {
+    testthat::skip("No internet connection, skipping tests")
+  }
+}
+
 skip_if_no_auth <- function(service) {
   if (identical(Sys.getenv(service), "")) {
     testthat::skip(glue::glue("No authentication available for {service}"))
@@ -203,14 +230,68 @@ main_test_battery <- function(test_object, ...) {
   }
 }
 
-unnest_debug <- function(x, ...) {
+# unnest_debug <- function(x, ...) {
+#
+#   if (inherits(x, 'list')) {
+#     stop(glue::glue(
+#       "Something went wrong, no data.frame returned, but a list with the following names {names(x)} and the following contents {glue::glue_collapse(x, sep = '\n')}"
+#     ))
+#   }
+#
+#   return(tidyr::unnest(x, ...))
+#
+# }
 
-  if (inherits(x, 'list')) {
-    stop(glue::glue(
-      "Something went wrong, no data.frame returned, but a list with the following names {names(x)} and the following contents {glue::glue_collapse(x, sep = '\n')}"
-    ))
+
+# GET and xml2 safe functions -----------------------------------------------------
+
+# safe GET
+.safeGET <- function(...) {
+
+  # create safe version
+  sGET <- purrr::safely(httr::GET)
+
+  # get response
+  response <- sGET(...)
+
+  return(response)
+}
+
+# safe xml
+.safe_read_xml <- function(...) {
+
+  # create safe version
+  s_read_xml <- purrr::safely(xml2::read_xml)
+
+  # add user agent
+  response <- httr::with_config(
+    httr::user_agent('https://github.com/emf-creaf/meteospain'),
+    s_read_xml(...)
+  )
+
+  return(response)
+}
+
+# return the corresponding safe function for the type of API
+safe_api_access <- function(type = c('rest', 'xml'), ...) {
+
+  # select the api function (.safeGET for REST APIs, .safe_read_xml for xml)
+  api_access <- switch(
+    type,
+    'rest' = .safeGET,
+    'xml' = .safe_read_xml
+  )
+
+  response <- api_access(...)
+
+  # checks and errors
+  if (is.null(response$result)) {
+    din_dots <- rlang::list2(...)
+    stop(
+      glue::glue("Unable to connect to API at {din_dots[[1]]}: {response$error}\n"),
+      glue::glue("This usually happens when connection with {din_dots[[1]]} is not possible")
+    )
   }
 
-  return(tidyr::unnest(x, ...))
-
+  return(response$result)
 }
