@@ -1,9 +1,10 @@
 # skip if no key ----------------------------------------------------------------------------------------
 
 skip_if_no_auth('aemet')
+skip_if_no_internet()
 
 # aemet service options tests ---------------------------------------------------------------------------
-
+withr::local_options(list("keyring_backend" = "env"))
 test_that("aemet service options works", {
   expected_names <- c("resolution", "start_date", "end_date", "stations", "api_key")
   expect_type(aemet_options(api_key = 'tururu'), 'list')
@@ -27,7 +28,7 @@ test_that("aemet service options works", {
 test_that("aemet get info works", {
   api_options <- aemet_options(api_key = keyring::key_get('aemet'))
   test_object <- suppressMessages(get_stations_info_from('aemet', api_options))
-  expected_names <- c("service", "station_id", "station_name", "altitude", "geometry")
+  expected_names <- c("service", "station_id", "station_name", "station_province", "altitude", "geometry")
   main_test_battery(test_object, service = 'aemet', expected_names = expected_names)
 })
 
@@ -36,9 +37,10 @@ test_that("aemet get info works", {
 test_that("aemet current works", {
   # all stations
   api_options <- aemet_options('current_day', api_key = keyring::key_get('aemet'))
-  expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
+  test_object <- get_meteo_from('aemet', api_options)
+  # expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
   expected_names <- c(
-    "timestamp", "service", "station_id", "station_name", "altitude",
+    "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "temperature", "min_temperature", "max_temperature",
     "relative_humidity", "precipitation",
     "wind_direction", "wind_speed", "geometry"
@@ -47,7 +49,8 @@ test_that("aemet current works", {
   # some stations
   stations_to_check <- test_object[['station_id']][1:3]
   api_options$stations <- stations_to_check
-  expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
+  test_object <- get_meteo_from('aemet', api_options)
+  # expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
   main_test_battery(
     test_object, service = 'aemet',
     expected_names = expected_names, stations_to_check = stations_to_check, temperature = temperature
@@ -61,7 +64,8 @@ test_that("aemet daily works", {
     start_date = as.Date('2020-04-01'), end_date = as.Date('2020-05-01'),
     api_key = keyring::key_get('aemet')
   )
-  expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
+  test_object <- get_meteo_from('aemet', api_options)
+  # expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature", "min_temperature", "max_temperature",
@@ -71,7 +75,8 @@ test_that("aemet daily works", {
   # some stations
   stations_to_check <- test_object[['station_id']][1:3]
   api_options$stations <- stations_to_check
-  expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
+  test_object <- get_meteo_from('aemet', api_options)
+  # expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
   main_test_battery(
     test_object, service = 'aemet',
     expected_names = expected_names, stations_to_check = stations_to_check, temperature = mean_temperature
@@ -82,7 +87,8 @@ test_that("aemet daily works", {
     start_date = as.Date('2005-04-01'), end_date = as.Date('2005-05-01'),
     api_key = keyring::key_get('aemet')
   )
-  expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
+  test_object <- get_meteo_from('aemet', api_options)
+  # expect_message((test_object <- get_meteo_from('aemet', api_options)), 'Autorizado el uso')
   main_test_battery(test_object, service = 'aemet', expected_names = expected_names, temperature = mean_temperature)
   # all stations 1990's
   api_options <- aemet_options(
